@@ -1,4 +1,4 @@
-/*  Copyright (C) 1995, 2000 Free Software Foundation, Inc.
+/*  Copyright (C) 1995, 2000, 2001 Free Software Foundation, Inc.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,10 +17,11 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 #ifndef GETLINE_H_
 # define GETLINE_H_ 1
 
+# include <stddef.h>
 # include <stdio.h>
 
 # ifndef PARAMS
-#  if defined (__GNUC__) || __STDC__
+#  if __STDC__ || defined __GNUC__ || defined __SUNPRO_C || defined __cplusplus || __PROTOTYPES
 #   define PARAMS(args) args
 #  else
 #   define PARAMS(args) ()
