@@ -1,7 +1,7 @@
 /* GNU gettext - internationalization aids
-   Copyright (C) 1996 Free Software Foundation, Inc.
+   Copyright (C) 1996, 1998, 2000, 2001 Free Software Foundation, Inc.
 
-   This file was written by Peter Miller <pmiller@agso.gov.au>
+   This file was written by Peter Miller <millerp@canb.auug.org.au>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -22,17 +22,17 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 #include "config.h"
 #endif
 
-#ifdef STDC_HEADERS
-# include <stdlib.h>
-#endif
-
-#include "system.h"
+/* Specification.  */
 #include "dir-list.h"
+
+#include <stddef.h>
+
 #include "str-list.h"
 
-static string_list_ty *directory;
+static string_list_ty *directory /* = NULL */;
 
 
+/* Append a directory to the end of the list of directories.  */
 void
 dir_list_append (s)
      const char *s;
@@ -43,12 +43,15 @@ dir_list_append (s)
 }
 
 
+/* Return the nth directory, or NULL of n is out of range.  */
 const char *
 dir_list_nth (n)
      int n;
 {
+  /* The default value of the list consists of the single directory ".".  */
   if (directory == NULL)
     dir_list_append (".");
+
   if (n < 0 || n >= directory->nitems)
     return NULL;
   return directory->item[n];
