@@ -47,8 +47,10 @@ const char *const format_language[NFORMATS] =
   /* format_librep */		"librep",
   /* format_smalltalk */	"smalltalk",
   /* format_java */		"java",
+  /* format_awk */		"awk",
   /* format_pascal */		"object-pascal",
-  /* format_ycp */		"ycp"
+  /* format_ycp */		"ycp",
+  /* format_tcl */		"tcl"
 };
 
 const char *const format_language_pretty[NFORMATS] =
@@ -60,12 +62,14 @@ const char *const format_language_pretty[NFORMATS] =
   /* format_librep */		"librep",
   /* format_smalltalk */	"Smalltalk",
   /* format_java */		"Java",
+  /* format_awk */		"awk",
   /* format_pascal */		"Object Pascal",
-  /* format_ycp */		"YCP"
+  /* format_ycp */		"YCP",
+  /* format_tcl */		"Tcl"
 };
 
 
-int
+bool
 possible_format_p (is_format)
      enum is_format is_format;
 {
