@@ -63,6 +63,7 @@ static const struct option long_options[] =
   { "indent", no_argument, NULL, 'i' },
   { "no-escape", no_argument, NULL, 'e' },
   { "no-location", no_argument, &line_comment, 0 },
+  { "no-wrap", no_argument, NULL, CHAR_MAX + 2 },
   { "omit-header", no_argument, NULL, CHAR_MAX + 1 },
   { "output", required_argument, NULL, 'o' }, /* for backward compatibility */
   { "output-file", required_argument, NULL, 'o' },
@@ -219,6 +220,10 @@ main (argc, argv)
 	omit_header = true;
 	break;
 
+      case CHAR_MAX + 2: /* --no-wrap */
+	message_page_width_ignore ();
+	break;
+
       default:
 	usage (EXIT_FAILURE);
 	/* NOTREACHED */
@@ -369,6 +374,8 @@ Output details:\n\
   -n, --add-location             generate '#: filename:line' lines (default)\n\
       --strict                   write out strict Uniforum conforming .po file\n\
   -w, --width=NUMBER             set output page width\n\
+      --no-wrap                  do not break long message lines, longer than\n\
+                                 the output page width, into several lines\n\
   -s, --sort-output              generate sorted output\n\
   -F, --sort-by-file             sort output by file location\n\
       --omit-header              don't write header with `msgid \"\"' entry\n\
