@@ -38,12 +38,14 @@
 #include "format.h"
 #include "xmalloc.h"
 #include "plural-exp.h"
+#include "plural-table.h"
 #include "strstr.h"
 #include "stpcpy.h"
 #include "exit.h"
 #include "msgfmt.h"
 #include "write-mo.h"
 #include "write-java.h"
+#include "write-tcl.h"
 
 #include "gettext.h"
 #include "message.h"
@@ -91,6 +93,11 @@ static const char *java_resource_name;
 static const char *java_locale_name;
 static const char *java_class_directory;
 
+/* Tcl mode output file specification.  */
+static bool tcl_mode;
+static const char *tcl_locale_name;
+static const char *tcl_base_directory;
+
 /* We may have more than one input file.  Domains with same names in
    different files have to merged.  So we need a list of tables for
    each output file.  */
@@ -162,6 +169,7 @@ static const struct option long_options[] =
   { "resource", required_argument, NULL, 'r' },
   { "statistics", no_argument, &do_statistics, 1 },
   { "strict", no_argument, NULL, 'S' },
+  { "tcl", no_argument, NULL, CHAR_MAX + 7 },
   { "use-fuzzy", no_argument, NULL, 'f' },
   { "verbose", no_argument, NULL, 'v' },
   { "version", no_argument, NULL, 'V' },
@@ -265,6 +273,7 @@ main (argc, argv)
 	break;
       case 'd':
 	java_class_directory = optarg;
+	tcl_base_directory = optarg;
 	break;
       case 'D':
 	dir_list_append (optarg);
@@ -280,6 +289,7 @@ main (argc, argv)
 	break;
       case 'l':
 	java_locale_name = optarg;
+	tcl_locale_name = optarg;
 	break;
       case 'o':
 	output_file_name = optarg;
@@ -325,6 +335,9 @@ main (argc, argv)
       case CHAR_MAX + 6:
 	no_hash_table = true;
 	break;
+      case CHAR_MAX + 7:
+	tcl_mode = true;
+	break;
       default:
 	usage (EXIT_FAILURE);
 	break;
@@ -356,18 +369,43 @@ warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\
     }
 
   /* Check for contradicting options.  */
+  if (java_mode && tcl_mode)
+    error (EXIT_FAILURE, 0, _("%s and %s are mutually exclusive"),
+	   "--java", "--tcl");
   if (java_mode)
     {
       if (output_file_name != NULL)
 	{
 	  error (EXIT_FAILURE, 0, _("%s and %s are mutually exclusive"),
-		 "--java-mode", "--output-file");
+		 "--java", "--output-file");
 	}
       if (java_class_directory == NULL)
 	{
 	  error (EXIT_SUCCESS, 0,
 		 _("%s requires a \"-d directory\" specification"),
-		 "--java-mode");
+		 "--java");
+	  usage (EXIT_FAILURE);
+	}
+    }
+  else if (tcl_mode)
+    {
+      if (output_file_name != NULL)
+	{
+	  error (EXIT_FAILURE, 0, _("%s and %s are mutually exclusive"),
+		 "--tcl", "--output-file");
+	}
+      if (tcl_locale_name == NULL)
+	{
+	  error (EXIT_SUCCESS, 0,
+		 _("%s requires a \"-l locale\" specification"),
+		 "--tcl");
+	  usage (EXIT_FAILURE);
+	}
+      if (tcl_base_directory == NULL)
+	{
+	  error (EXIT_SUCCESS, 0,
+		 _("%s requires a \"-d directory\" specification"),
+		 "--tcl");
 	  usage (EXIT_FAILURE);
 	}
     }
@@ -376,19 +414,19 @@ warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\
       if (java_resource_name != NULL)
 	{
 	  error (EXIT_SUCCESS, 0, _("%s is only valid with %s"),
-		 "--resource", "--java-mode");
+		 "--resource", "--java");
 	  usage (EXIT_FAILURE);
 	}
       if (java_locale_name != NULL)
 	{
-	  error (EXIT_SUCCESS, 0, _("%s is only valid with %s"),
-		 "--locale", "--java-mode");
+	  error (EXIT_SUCCESS, 0, _("%s is only valid with %s or %s"),
+		 "--locale", "--java", "--tcl");
 	  usage (EXIT_FAILURE);
 	}
       if (java_class_directory != NULL)
 	{
-	  error (EXIT_SUCCESS, 0, _("%s is only valid with %s"),
-		 "-d", "--java-mode");
+	  error (EXIT_SUCCESS, 0, _("%s is only valid with %s or %s"),
+		 "-d", "--java", "--tcl");
 	  usage (EXIT_FAILURE);
 	}
     }
@@ -439,6 +477,12 @@ warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\
 				    assume_java2))
 	    exit_status = EXIT_FAILURE;
 	}
+      else if (tcl_mode)
+	{
+	  if (msgdomain_write_tcl (domain->mlp,
+				   tcl_locale_name, tcl_base_directory))
+	    exit_status = EXIT_FAILURE;
+	}
       else
 	{
 	  if (msgdomain_write_mo (domain->mlp, domain->domain_name,
@@ -513,6 +557,7 @@ If input file is -, standard input is read.\n\
 Operation mode:\n\
   -j, --java                  Java mode: generate a Java ResourceBundle class\n\
       --java2                 like --java, and assume Java2 (JDK 1.2 or higher)\n\
+      --tcl                   Tcl mode: generate a tcl/msgcat .msg file\n\
 "));
       printf ("\n");
       /* xgettext: no-wrap */
@@ -532,6 +577,15 @@ Output file location in Java mode:\n\
 The class name is determined by appending the locale name to the resource name,\n\
 separated with an underscore.  The -d option is mandatory.  The class is\n\
 written under the specified directory.\n\
+"));
+      printf ("\n");
+      /* xgettext: no-wrap */
+      printf (_("\
+Output file location in Tcl mode:\n\
+  -l, --locale=LOCALE         locale name, either language or language_COUNTRY\n\
+  -d DIRECTORY                base directory of .msg message catalogs\n\
+The -l and -d options are mandatory.  The .msg file is written in the\n\
+specified directory.\n\
 "));
       printf ("\n");
       /* xgettext: no-wrap */
@@ -796,32 +850,36 @@ check_plural (mlp)
   min_pos = NULL;
   max_nplurals = 0;
   max_pos = NULL;
-  for (j = 0; j < mlp->nitems; j++) {
-    message_ty *mp = mlp->item[j];
+  for (j = 0; j < mlp->nitems; j++)
+    {
+      message_ty *mp = mlp->item[j];
 
-    if (mp->msgid_plural != NULL) {
-      const char *p;
-      const char *p_end;
-      unsigned long n;
+      if (mp->msgid_plural != NULL)
+	{
+	  const char *p;
+	  const char *p_end;
+	  unsigned long n;
 
-      if (has_plural == NULL)
-	has_plural = &mp->pos;
+	  if (has_plural == NULL)
+	    has_plural = &mp->pos;
 
-      n = 0;
-      for (p = mp->msgstr, p_end = p + mp->msgstr_len;
-	   p < p_end;
-	   p += strlen (p) + 1)
-	n++;
-      if (min_nplurals > n) {
-	min_nplurals = n;
-	min_pos = &mp->pos;
-      }
-      if (max_nplurals > n) {
-	max_nplurals = n;
-	min_pos = &mp->pos;
-      }
+	  n = 0;
+	  for (p = mp->msgstr, p_end = p + mp->msgstr_len;
+	       p < p_end;
+	       p += strlen (p) + 1)
+	    n++;
+	  if (min_nplurals > n)
+	    {
+	      min_nplurals = n;
+	      min_pos = &mp->pos;
+	    }
+	  if (max_nplurals > n)
+	    {
+	      max_nplurals = n;
+	      min_pos = &mp->pos;
+	    }
+	}
     }
-  }
 
   /* Look at the plural entry for this domain.
      Cf, function extract_plural_expression.  */
@@ -831,6 +889,7 @@ check_plural (mlp)
       const char *nullentry;
       const char *plural;
       const char *nplurals;
+      bool try_to_help = false;
 
       nullentry = header->msgstr;
 
@@ -845,6 +904,7 @@ check_plural (mlp)
 	  error_at_line (0, 0, header->pos.file_name, header->pos.line_number,
 			 _("...but header entry lacks a \"plural=EXPRESSION\" attribute"));
 	  error_with_progname = true;
+	  try_to_help = true;
 	  exit_status = EXIT_FAILURE;
 	}
       if (nplurals == NULL && has_plural != NULL)
@@ -856,6 +916,7 @@ check_plural (mlp)
 	  error_at_line (0, 0, header->pos.file_name, header->pos.line_number,
 			 _("...but header entry lacks a \"nplurals=INTEGER\" attribute"));
 	  error_with_progname = true;
+	  try_to_help = true;
 	  exit_status = EXIT_FAILURE;
 	}
       if (plural != NULL && nplurals != NULL)
@@ -880,6 +941,7 @@ check_plural (mlp)
 			     header->pos.file_name, header->pos.line_number,
 			     _("invalid nplurals value"));
 	      error_with_progname = true;
+	      try_to_help = true;
 	      exit_status = EXIT_FAILURE;
 	    }
 
@@ -893,6 +955,7 @@ check_plural (mlp)
 			     header->pos.file_name, header->pos.line_number,
 			     _("invalid plural expression"));
 	      error_with_progname = true;
+	      try_to_help = true;
 	      exit_status = EXIT_FAILURE;
 	    }
 	  plural_expr = args.res;
@@ -939,6 +1002,32 @@ check_plural (mlp)
 		 max_nplurals = n = min_nplurals.  */
 	    }
 	}
+      /* Try to help the translator by looking up the right plural formula
+	 for her.  */
+      if (try_to_help)
+	{
+	  const char *language;
+
+	  language = strstr (nullentry, "Language-Team: ");
+	  if (language != NULL)
+	    {
+	      language += 15;
+	      for (j = 0; j < plural_table_size; j++)
+		if (strncmp (language,
+			     plural_table[j].language,
+			     strlen (plural_table[j].language)) == 0)
+		  {
+		    char *recommended =
+		      xasprintf ("Plural-Forms: %s\\n", plural_table[j].value);
+		    fprintf (stderr,
+			     _("Try using the following, valid for %s:\n"),
+			     plural_table[j].language);
+		    fprintf (stderr, "\"%s\"\n", recommended);
+		    free (recommended);
+		    break;
+		  }
+	    }
+	}
     }
   else if (has_plural != NULL)
     {
@@ -1145,11 +1234,14 @@ check_pair (msgid, msgid_pos, msgid_plural, msgstr, msgstr_len, msgstr_pos,
       p = strchr (msgid, accelerator_char);
       if (p != NULL && strchr (p + 1, accelerator_char) == NULL)
 	{
-	  /* Count the number of '&' in msgstr.  */
+	  /* Count the number of '&' in msgstr, but ignore '&&'.  */
 	  unsigned int count = 0;
 
 	  for (p = msgstr; (p = strchr (p, accelerator_char)) != NULL; p++)
-	    count++;
+	    if (p[1] == accelerator_char)
+	      p++;
+	    else
+	      count++;
 
 	  if (count == 0)
 	    {
@@ -1198,12 +1290,12 @@ check_header_entry (msgstr_string)
 
       if (endp == NULL)
 	multiline_error (xasprintf ("%s: ", gram_pos.file_name),
-			 xasprintf (_("headerfield `%s' missing in header"),
+			 xasprintf (_("headerfield `%s' missing in header\n"),
 				    required_fields[cnt]));
       else if (endp != msgstr_string && endp[-1] != '\n')
 	multiline_error (xasprintf ("%s: ", gram_pos.file_name),
 			 xasprintf (_("\
-header field `%s' should start at beginning of line"),
+header field `%s' should start at beginning of line\n"),
 				    required_fields[cnt]));
       else if (default_values[cnt] != NULL
 	       && strncmp (default_values[cnt],
@@ -1214,7 +1306,7 @@ header field `%s' should start at beginning of line"),
 	    {
 	      multiline_error (xasprintf ("%s: ", gram_pos.file_name),
 			       xstrdup (_("\
-some header fields still have the initial default value")));
+some header fields still have the initial default value\n")));
 	      initial = -1;
 	      break;
 	    }
@@ -1225,7 +1317,8 @@ some header fields still have the initial default value")));
 
   if (initial != -1)
     multiline_error (xasprintf ("%s: ", gram_pos.file_name),
-		     xasprintf (_("field `%s' still has initial default value"),
+		     xasprintf (_("\
+field `%s' still has initial default value\n"),
 				required_fields[initial]));
 }
 
@@ -1296,7 +1389,7 @@ format_directive_domain (pop, name)
 {
   /* If no output file was given, we change it with each `domain'
      directive.  */
-  if (!java_mode && output_file_name == NULL)
+  if (!java_mode && !tcl_mode && output_file_name == NULL)
     {
       size_t correct;
 
