@@ -7,6 +7,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <locale.h>
+#include "xsetenv.h"
 
 /* Make sure we use the included libintl, not the system's one. */
 #define textdomain textdomain__
@@ -19,8 +20,9 @@ int main (argc, argv)
   int argc;
   char *argv[];
 {
-  int n = atoi (argv[1]);
+  int n = atoi (argv[2]);
 
+  xsetenv ("LC_ALL", argv[1], 1);
   if (setlocale (LC_ALL, "") == NULL)
     return 1;
 
